==> ejc-bfyjerp-api-3.0.0-20250224.034732-141-sources.jar: com/ejianc/business/oa/vo/CertRecordDetailVO.java <==
package com.ejianc.business.oa.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 人力行政-证书档案-证件信息
 * 
 * @author generator
 * 
 */
public class CertRecordDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long recordId; // 证书档案id
    private String certTypeName; // 证照类别
    private String certName; // 证照名称
    private Long certNameId; // 证照名称
    private String certCode; // 证照编号
    private String certMajor; // 证照专业
    private Long certMajorId; // 证照专业名称
    private String sealMajor; // 印章专业
    private String authorities; // 发证机关
    private String approveNum; // 批准文号
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date beginTime; // 生效日期
    private Integer term; // 有无期限 1：有 2：无
    private String termName; // 有无期限 1：有 2：无
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endTime; // 失效日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
        private Date electronCertDate; // 电子证照有效期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date sendCertDate; // 发证日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date addDate; // 加注有效期
    private Integer certState; // 证书使用状态
    private String certStateName; // 证书使用状态
    private String place; // 存放地点
    private Long orgDetailId; // 组织ID
    private String orgDetailName; // 组织
    private Long certType; // 证照类别
    public Long getRecordId() {
        return recordId;
    }

    public Long getCertNameId() {
        return certNameId;
    }

    public void setCertNameId(Long certNameId) {
        this.certNameId = certNameId;
    }

    public Long getCertMajorId() {
        return certMajorId;
    }

    public void setCertMajorId(Long certMajorId) {
        this.certMajorId = certMajorId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }
    public String getCertTypeName() {
        return certTypeName;
    }

    public void setCertTypeName(String certTypeName) {
        this.certTypeName = certTypeName;
    }
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }
    public String getCertCode() {
        return certCode;
    }

    public void setCertCode(String certCode) {
        this.certCode = certCode;
    }
    public String getCertMajor() {
        return certMajor;
    }

    public void setCertMajor(String certMajor) {
        this.certMajor = certMajor;
    }
    public String getSealMajor() {
        return sealMajor;
    }

    public void setSealMajor(String sealMajor) {
        this.sealMajor = sealMajor;
    }
    public String getAuthorities() {
        return authorities;
    }

    public void setAuthorities(String authorities) {
        this.authorities = authorities;
    }
    public String getApproveNum() {
        return approveNum;
    }

    public void setApproveNum(String approveNum) {
        this.approveNum = approveNum;
    }
    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }
    public Integer getTerm() {
        return term;
    }

    public void setTerm(Integer term) {
        this.term = term;
    }
    public String getTermName() {
        return termName;
    }

    public void setTermName(String termName) {
        this.termName = termName;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public Date getElectronCertDate() {
        return electronCertDate;
    }

    public void setElectronCertDate(Date electronCertDate) {
        this.electronCertDate = electronCertDate;
    }
    public Date getSendCertDate() {
        return sendCertDate;
    }

    public void setSendCertDate(Date sendCertDate) {
        this.sendCertDate = sendCertDate;
    }
    public Date getAddDate() {
        return addDate;
    }

    public void setAddDate(Date addDate) {
        this.addDate = addDate;
    }
    public Integer getCertState() {
        return certState;
    }

    public void setCertState(Integer certState) {
        this.certState = certState;
    }
    public String getCertStateName() {
        return certStateName;
    }

    public void setCertStateName(String certStateName) {
        this.certStateName = certStateName;
    }
    public String getPlace() {
        return place;
    }
    @ReferSerialTransfer(referCode="support-defdoc")
    public Long getCertType() {
        return certType;
    }
    @ReferDeserialTransfer
    public void setCertType(Long certType) {
        this.certType = certType;
    }

    public void setPlace(String place) {
        this.place = place;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgDetailId() {
        return orgDetailId;
    }
    @ReferDeserialTransfer
    public void setOrgDetailId(Long orgDetailId) {
        this.orgDetailId = orgDetailId;
    }
    public String getOrgDetailName() {
        return orgDetailName;
    }

    public void setOrgDetailName(String orgDetailName) {
        this.orgDetailName = orgDetailName;
    }
    
}

==> ejc-bfyjerp-api-3.0.0-20250224.075707-143-sources.jar: com/ejianc/business/oa/vo/CertRecordDetailVO.java <==
package com.ejianc.business.oa.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 人力行政-证书档案-证件信息
 * 
 * @author generator
 * 
 */
public class CertRecordDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long recordId; // 证书档案id
    private String certTypeName; // 证照类别
    private String certName; // 证照名称
    private Long certNameId; // 证照名称
    private String certCode; // 证照编号
    private String certMajor; // 证照专业
    private Long certMajorId; // 证照专业名称
    private String sealMajor; // 印章专业
    private String authorities; // 发证机关
    private String approveNum; // 批准文号
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date beginTime; // 生效日期
    private Integer term; // 有无期限 1：有 2：无
    private String termName; // 有无期限 1：有 2：无
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date endTime; // 失效日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
        private Date electronCertDate; // 电子证照有效期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date sendCertDate; // 发证日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date addDate; // 加注有效期
    private Integer certState; // 证书使用状态
    private String certStateName; // 证书使用状态
    private String place; // 存放地点
    private Long orgDetailId; // 组织ID
    private String orgDetailName; // 组织
    private Long certType; // 证照类别
    public Long getRecordId() {
        return recordId;
    }

    @ReferSerialTransfer(referCode="bfyj-cert-type")
    public Long getCertNameId() {
        return certNameId;
    }

    @ReferDeserialTransfer
    public void setCertNameId(Long certNameId) {
        this.certNameId = certNameId;
    }

    @ReferSerialTransfer(referCode="bfyj-cert-type")
    public Long getCertMajorId() {
        return certMajorId;
    }

    @ReferDeserialTransfer
    public void setCertMajorId(Long certMajorId) {
        this.certMajorId = certMajorId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }
    public String getCertTypeName() {
        return certTypeName;
    }

    public void setCertTypeName(String certTypeName) {
        this.certTypeName = certTypeName;
    }
    public String getCertName() {
        return certName;
    }

    public void setCertName(String certName) {
        this.certName = certName;
    }
    public String getCertCode() {
        return certCode;
    }

    public void setCertCode(String certCode) {
        this.certCode = certCode;
    }
    public String getCertMajor() {
        return certMajor;
    }

    public void setCertMajor(String certMajor) {
        this.certMajor = certMajor;
    }
    public String getSealMajor() {
        return sealMajor;
    }

    public void setSealMajor(String sealMajor) {
        this.sealMajor = sealMajor;
    }
    public String getAuthorities() {
        return authorities;
    }

    public void setAuthorities(String authorities) {
        this.authorities = authorities;
    }
    public String getApproveNum() {
        return approveNum;
    }

    public void setApproveNum(String approveNum) {
        this.approveNum = approveNum;
    }
    public Date getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(Date beginTime) {
        this.beginTime = beginTime;
    }
    public Integer getTerm() {
        return term;
    }

    public void setTerm(Integer term) {
        this.term = term;
    }
    public String getTermName() {
        return termName;
    }

    public void setTermName(String termName) {
        this.termName = termName;
    }
    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }
    public Date getElectronCertDate() {
        return electronCertDate;
    }

    public void setElectronCertDate(Date electronCertDate) {
        this.electronCertDate = electronCertDate;
    }
    public Date getSendCertDate() {
        return sendCertDate;
    }

    public void setSendCertDate(Date sendCertDate) {
        this.sendCertDate = sendCertDate;
    }
    public Date getAddDate() {
        return addDate;
    }

    public void setAddDate(Date addDate) {
        this.addDate = addDate;
    }
    public Integer getCertState() {
        return certState;
    }

    public void setCertState(Integer certState) {
        this.certState = certState;
    }
    public String getCertStateName() {
        return certStateName;
    }

    public void setCertStateName(String certStateName) {
        this.certStateName = certStateName;
    }
    public String getPlace() {
        return place;
    }
    @ReferSerialTransfer(referCode="bfyj-cert-type")
    public Long getCertType() {
        return certType;
    }
    @ReferDeserialTransfer
    public void setCertType(Long certType) {
        this.certType = certType;
    }

    public void setPlace(String place) {
        this.place = place;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgDetailId() {
        return orgDetailId;
    }
    @ReferDeserialTransfer
    public void setOrgDetailId(Long orgDetailId) {
        this.orgDetailId = orgDetailId;
    }
    public String getOrgDetailName() {
        return orgDetailName;
    }

    public void setOrgDetailName(String orgDetailName) {
        this.orgDetailName = orgDetailName;
    }
    
}
